@@ -1,12 +1,12 @@
 extern crate timeout_readwrite;
 
 use std::env;
-use std::io::{BufRead, BufReader};
 use std::io::Result;
+use std::io::{BufRead, BufReader};
 use std::process;
 use std::time::Duration;
 
-use timeout_readwrite::TimeoutReader;
+use timeout_readwrite::TimeoutReadExt;
 
 fn each_line<R: BufRead>(rdr: R) -> Result<()> {
     let lines = rdr.lines();
@@ -25,13 +25,14 @@ fn do_command<I: Iterator<Item = String>>(mut args: I) -> Result<()> {
         cmd.arg(arg);
     }
 
-    let child = cmd.stdout(process::Stdio::piped())
+    let child = cmd
+        .stdout(process::Stdio::piped())
         .stderr(process::Stdio::null())
         .spawn()
         .expect("spawning did not succeed");
 
     let stdout = child.stdout.expect("stdout must be there");
-    each_line(BufReader::new(TimeoutReader::new(stdout, Duration::new(5, 0))))
+    each_line(BufReader::new(stdout.with_timeout(Duration::new(5, 0))))
 }
 
 fn main() {
